/*
** Module   : NativeInteger.java
** Abstract : descriptor for integer data as an argument or return value to a native function 
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 GES 20131212 First version.
*/

package com.goldencode.p2j.library;

import java.io.*;
import com.goldencode.p2j.util.*;

/**
 * A descriptor for integer data as an argument or return value to a native function.
 */
public abstract class NativeInteger
extends NativePrimitive
{
   /** The stored value. */
   protected long value; 
   
   /**
    * Default constructor.
    */
   public NativeInteger()
   {
      super();
   }
   
   /**
    * Access the data element.
    *
    * @return   The integer data element.
    */
   public long getValue()
   {
      return value;
   }
   
   /**
    * Assign the data element.
    *
    * @param    value
    *           The new integer data element.
    */
   public void setValue(long value)
   {
      this.value = value;
   }
   
   /**
    * Replacement for the default object reading method. The latest
    * state is read from the input source.  The parent's state is
    * read first.
    * 
    * @param    in
    *           The input source from which fields will be restored.
    *
    * @throws   IOException
    *           In case of I/O errors.
    * @throws   ClassNotFoundException
    *           If payload can't be instantiated.
    */
   public void readExternal(ObjectInput in)
   throws IOException,
          ClassNotFoundException
   {
      super.readExternal(in);
      value = in.readLong();
   }

   /**
    * Replacement for the default object writing method. The latest
    * state is written to the output destination.  The parent's state is
    * written first.
    * 
    * @param    out
    *           The output destination to which fields will be saved.
    *
    * @throws   IOException
    *           In case of I/O errors.
    */
   public void writeExternal(ObjectOutput out)
   throws IOException
   {
      super.writeExternal(out);
      out.writeLong(value);
   }
}
