/*
** Module   : NativeSignedInt64.java
** Abstract : descriptor for a signed 64-bit integer 
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 GES 20131212 First version.
*/

package com.goldencode.p2j.library;

import java.io.*;
import com.goldencode.p2j.util.*;

/**
 * A descriptor for a signed short.
 */
public class NativeSignedInt64 
extends NativeInteger
{
   /**
    * Default constructor.
    */
   public NativeSignedInt64()
   {
      super();
      type = LibraryManager.TYPE_SIGNED_INT64;
   }
   
   /**
    * Report the size (in bytes) of the native memory needed to store this instance.
    * <p>
    * This should never be called on the server, only on the client side.
    *
    * @return   The number of bytes needed.
    */
   public int size()
   {
      return 8;
   }
   
   /**
    * Worker method to read the primitive value from the first index position of the given
    * memory buffer.
    *
    * @param    ptr
    *           The memory buffer to reference.
    */
   protected void readNative(memptr ptr)
   {
      int64 num = ptr.getInt64(1);
      
      if (!num.isUnknown())
      {
         value = num.longValue();
      }
   }
   
   /**
    * Worker method to write the primitive value to the first index position of the given
    * memory buffer.
    *
    * @param    ptr
    *           The memory buffer to reference.
    */
   protected void writeNative(memptr ptr)
   {
      ptr.setInt64(value, 1);
   }
}
